<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO; 
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities\ChunkReadFilter;

class AutoImposto extends CrudWithParameterBag {

	protected $dataSourceName = 'paraVendasImpostoProdutoSwipe';
	protected $parameterBagColumns = array('NRORG', 'CDFILIAL');
	protected $AutoImpostoService;
	
	public static $logMessages = array();

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, $connection, Services\AutoImpostoService $AutoImpostoService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->connection = $connection;
        $this->AutoImpostoService = $AutoImpostoService;
    }
    
    public static function escreverLog ($data) {
        array_push(self::$logMessages, $data);
    }
    
    public static function escreverLogArray($array) {
        foreach ($array as $linha) {
            self::escreverLog($linha);
        }
    }
    
    public static function getLog () {
        return self::$logMessages;
    }

    public function saveImpostoAuto (DTO\Request\DataSet $request, DTO\Response $response) {
        
        $row = $request->getDataSet()->getRows();
        if(count($row) > 1){
            $newRow =[];
            array_push($newRow, $row[1]);
        }else {
            $newRow = $row;
        }
        
        
        $request->getDataSet()->setDataSourceName('paraVendasImpostoProdutoSwipe');
        if(isset($newRow[0]['CDPRODUTOINI'])){
        	$params = array (
        	    ':CDFILIAL'    => $newRow[0]['CDFILIAL'],
        	    ':NRORG'       => $newRow[0]['NRORG'],
        	    ':CDNVPRODUTO' => $newRow[0]['CDNVPRODUTO'],
        	    ':CDARVPRODINI'=> $newRow[0]['CDARVPRODINI'],
        	    ':CDARVPRODFIN'=> $newRow[0]['CDARVPRODFIN']
        	);
        
            $productsAlreadyRegistered = $this->AutoImpostoService->getProductsAlreadyRegisteredBetween($params);
            $productsAlreadyRegistered = $this->productsToUpdate($productsAlreadyRegistered, $newRow[0]);
            
			$prodlist = $this->AutoImpostoService->getProductToRegister($params);
			$prodlist = array_column($prodlist, 'CDPRODUTO');
			
            $newRow[0] = $this->fixSaveImpostoProdutosParameters($newRow[0]);
            $AlreadyInsert = array();
            foreach ($productsAlreadyRegistered as $product) {
                $product = $this->fixSaveImpostoProdutosParameters($product);
                $this->AutoImpostoService->updateProductAliqAuto($product);
                $AlreadyInsert[$product['CDPRODUTO']] = $product['CDPRODUTO'];
            }
            
            $this->AutoImpostoService->saveProdutosImpostoLista($prodlist, $newRow[0], $AlreadyInsert);
            
            $response->addDataSet(new DataSet($this->dataSourceName, $prodlist));
            
        }else{
           
        	$prodlist = $newRow[0]['CDPRODUTO_SM'];
			$this->buildParams('CDPRODUTO_SM', $newRow[0]);
			
        	$params = array (
        	    ':CDFILIAL'  => $newRow[0]['CDFILIAL'],
        	    ':NRORG'     => $newRow[0]['NRORG'],
        	    ':CDPRODUTO' => $newRow[0]['CDPRODUTO_SM']
        	);
        	
            $productsAlreadyRegistered = $this->AutoImpostoService->getProductsAlreadyRegistered($params);
            $productsAlreadyRegistered = $this->productsToUpdate($productsAlreadyRegistered, $newRow[0]);
            $newRow[0] = $this->fixSaveImpostoProdutosParameters($newRow[0]);
            $AlreadyInsert = array();
            foreach ($productsAlreadyRegistered as $product) {
                $product = $this->fixSaveImpostoProdutosParameters($product);
                $this->AutoImpostoService->updateProductAliqAuto($product);
                $AlreadyInsert[$product['CDPRODUTO']] = $product['CDPRODUTO'];
            }
           
					
             
            $this->AutoImpostoService->saveProdutosImpostoLista($prodlist, $newRow[0], $AlreadyInsert);
            
            $response->addDataSet(new DataSet($this->dataSourceName, $prodlist));

            
        }
    }
    
    private function productsToUpdate($productToUpdate, $productFromFront){
        $updateProduct = [];
        foreach ($productToUpdate as $product) {
            if($product['FLAG'] == 'OLD'){
                $product['VRPEALIMPFIS']    = $productFromFront['VRPEALIMPFIS'] == 0 ? $productFromFront['VRPEALIMPFIS'] :  $productFromFront['VRPEALIMPFIS']; 
                $product['VRALIQIBPTES']    = $productFromFront['VRALIQIBPTES'] == 0 ? $product['VRALIQIBPTES'] :  $productFromFront['VRALIQIBPTES']; 
                $product['VRALIQIBPT']      = $productFromFront['VRALIQIBPT'] == 0 ? $product['VRALIQIBPT'] :  $productFromFront['VRALIQIBPT']; 
                $product['CDCFOPPFIS']      = $productFromFront['CDCFOPPFIS'] == '' ? $product['CDCFOPPFIS'] :  $productFromFront['CDCFOPPFIS']; 
                $product['CDCSTICMS']       = $productFromFront['CDCSTICMS'] == '' ? $product['CDCSTICMS'] :  $productFromFront['CDCSTICMS']; 
                $product['IDINCIDEPISCOF']  = $productFromFront['IDINCIDEPISCOF'];
                $product['VRPERCREDUCAO']   = $productFromFront['TIPOREDBASE'] == 'N' ? $product['VRPERCREDUCAO'] :  $productFromFront['VRPERCREDUCAO']; 
                $product['IDMODALBASECALC'] = $productFromFront['TIPOREDBASE'] == 'N' ? $product['IDMODALBASECALC'] :  $productFromFront['IDMODALBASECALC']; 
                $product['CDCSTPISCOF']     = $productFromFront['TIPOCST'] == 'N' ? $product['CDCSTPISCOF'] :  $productFromFront['CDCSTPISCOF']; 
                $product['VRALIQPIS']       = $productFromFront['TIPOCST'] == 'N' ? $product['VRALIQPIS'] :  $productFromFront['VRALIQPIS']; 
                $product['VRALIQCOFINS']    = $productFromFront['TIPOCST'] == 'N'? $product['VRALIQCOFINS'] :  $productFromFront['VRALIQCOFINS']; 
                $product['CDIMPOSTO']       = $productFromFront['CDIMPOSTO']; 
                $product['IDTPIMPOSFIS']    = $productFromFront['IDTPIMPOSFIS'];
                $product['VRALIQFCP']       = $productFromFront['VRALIQFCP'];
                $product['VRPEALIMPFISEF']  = $productFromFront['VRPEALIMPFISEF'];
                $product['VRPERCREDUCAOEF'] = $productFromFront['VRPERCREDUCAOEF'];
                $product['CDCBENEF']        = $productFromFront['CDCBENEF'];
                $product['VRALIQICMSDES']   = $productFromFront['VRALIQICMSDES'];
                array_push($updateProduct, $product);
            }
        }
        return $updateProduct;
    }
    
    private function createFilterCriteria($params) {
        $filterCriteria = new FilterCriteria ($this->dataSourceName);
        foreach($params as $name => $value) {
            $filterCriteria->addCondition($name, '=', $value);
        }
        return $filterCriteria;
    }
     
    private function buildParams ($key, $conditions){
       $conditions[$key] = implode('_', $conditions[$key]);
       $conditions['T'.$key] = '';
       return $conditions;
    }
    
    private function fixSaveImpostoProdutosParameters($row) {
        $row['VRPEALIMPFIS']    = array_key_exists('VRPEALIMPFIS', $row)    ? $row['VRPEALIMPFIS']      : null; 
        $row['VRPERCREDUCAO']   = array_key_exists('VRPERCREDUCAO', $row)   ? $row['VRPERCREDUCAO']     : null; 
        $row['IDMODALBASECALC'] = array_key_exists('IDMODALBASECALC', $row) ? $row['IDMODALBASECALC']   : null; 
        $row['IDINCIDEPISCOF']  = array_key_exists('IDINCIDEPISCOF', $row)  ? $row['IDINCIDEPISCOF']    : null; 
        $row['VRALIQIBPT']      = array_key_exists('VRALIQIBPT', $row)      ? $row['VRALIQIBPT']        : null; 
        $row['VRALIQIBPTES']    = array_key_exists('VRALIQIBPTES', $row)    ? $row['VRALIQIBPTES']      : null; 
        $row['CDCFOPPFIS']      = array_key_exists('CDCFOPPFIS', $row)      ? $row['CDCFOPPFIS']        : null; 
        $row['CDCSTICMS']       = array_key_exists('CDCSTICMS', $row)       ? $row['CDCSTICMS']         : null; 
        $row['CDCSTPISCOF']     = array_key_exists('CDCSTPISCOF', $row)     ? $row['CDCSTPISCOF']       : null; 
        $row['VRALIQPIS']       = array_key_exists('VRALIQPIS', $row)       ? $row['VRALIQPIS']         : null; 
        $row['VRALIQCOFINS']    = array_key_exists('VRALIQCOFINS', $row)    ? $row['VRALIQCOFINS']      : null;
        $row['CDCEST']          = array_key_exists('CDCEST', $row)          ? $row['CDCEST']            : null;
        $row['VRALIQFCP']       = array_key_exists('VRALIQFCP', $row)       ? $row['VRALIQFCP']         : null;  
        $row['VRPEALIMPFISEF']  = array_key_exists('VRPEALIMPFISEF', $row)  ? $row['VRPEALIMPFISEF']    : null;
        $row['VRPERCREDUCAOEF'] = array_key_exists('VRPERCREDUCAOEF', $row) ? $row['VRPERCREDUCAOEF']   : null;
        $row['CDCBENEF']        = array_key_exists('CDCBENEF', $row)        ? $row['CDCBENEF']          : null;
        $row['VRALIQICMSDES']   = array_key_exists('VRALIQICMSDES', $row)   ? $row['VRALIQICMSDES']     : null;

        $row['__is_new'] = true;
        
        return $row;
    }
    
    public function uploadXLS(Request\DataSet $request, Response $response){
        
        try {
            
            $rows = $request->getDataSet()->getRows()[0];
            $errors = '';
            $array = array(
                "path" => '',
                "file" => '',
                "status" => false,
                'message' => '',
                'filial' => '',
                'nameFile' => '',
                'checkDuplicidade' => []
            );
            
            //extensoes permitidas
            $allowed_ext = array('xlsx', 'xls', 'ods', 'ots');
            
            $dirFile = "/tmp/";
            $success = '';
            
            if(!empty($rows['ARQEXCEL'])){
                foreach ($rows['ARQEXCEL'] as $key => $value) {
                    $array['nameFile'] = $value['name'];
                    $ext_type = explode('.', $this->tratarNomeArquivo(utf8_decode($value['name'])));
                    
                    if(in_array($ext_type[1], $allowed_ext) === false){
                         $errors .= ' Extensão não Permitida!';
                    }
                    if($value['size'] > 1048576){
                        $errors .= ' Tamanho do arquivo deve ser até 1mb!';
                    }
                    if(empty($errors)){
                        $base64 = explode(",", $value['b64File']);
                    	$data = base64_decode($base64[1]);
                    	$fileName = uniqid().'.'.$ext_type[1];
                    	$file = $dirFile.$fileName;
                    	$array['path'] = $dirFile;
                    	$array['file'] = $fileName;
                    	$array['filial'] = $rows['CDFILIAL'];
                    	if(file_put_contents($file, $data)){
                    	    $array['status'] = true;
                    	    $array['message'] = 'Salvo com sucesso';
                    	}
                    }else{
                        $array['status'] = false;
                        $array['message'] = 'Não foi possível realizar o upload. '.$errors;
                    }
                }
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('resultado', $array));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
        
    }
    
    public function tratarNomeArquivo($string){
       // pegando a extensao do arquivo
       $partes 	= explode(".", $string);
       $extensao 	= $partes[count($partes)-1];	
       // somente o nome do arquivo
       $nome	= preg_replace('/\.[^.]*$/', '', $string);	
       // removendo simbolos, acentos etc
       $a = 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõöøùúûüýýþÿŔŕ?';
       $b = 'aaaaaaaceeeeiiiidnoooooouuuuybsaaaaaaaceeeeiiiidnoooooouuuuyybyRr-';
       $nome = strtr($nome, utf8_decode($a), $b);
       $nome = str_replace(".","-",$nome);
       $nome = preg_replace( "/[^0-9a-zA-Z\.]+/",'-',$nome);
       return utf8_decode(strtolower($nome.".".$extensao));
    }
    
    public function importarXLS(Request $request, Response $response){
        
        try {
            
            $rows = $request->getRow();
            
            ini_set('max_execution_time', 1800);
            ini_set('memory_limit', '500M');
            $array = array(
                "path" => '',
                "file" => '',
                "status" => '',
                "message" => '',
                "controle" => 1,
                "filial" => '',
                'totalSuccess' => 0,
                'totalError' => 0,
                'nameFile' => '',
                'checkDuplicidade' => []
            );
            
            if(!empty($rows['log'])){
                self::escreverLogArray($rows['log']);
            }else{
                self::escreverLog("## Importação Iniciada Data: ".date("d/m/Y H:i:s")." ##");
                self::escreverLog("## Arquivo importado: ".$rows['nameFile']." ##");
            }
            
            if(!empty($rows['diretorio']) && !empty($rows['file'])){
                
                $array['path'] = $rows['diretorio'];
                $array['file'] = $rows['file'];
                $array['filial'] = $rows['filial'];
                $array['nameFile'] = $rows['nameFile'];
                $array['stop'] = false;
                $array['totalSuccess'] = $rows['tSuccess'];
                $array['totalError'] = $rows['tError'];
                $array['checkDuplicidade'] = $rows['checkDuplicidade'];
                $array['ibpt'] = $rows['ibpt'];
                
                $fileName = $rows['diretorio'].$rows['file'];
                
                $objReader = \PHPExcel_IOFactory::createReaderForFile($fileName);
                
                $chunkSize = 100;
                $chunkFilter = new chunkReadFilter();
                $objReader->setReadDataOnly(true);
                $objReader->setReadFilter($chunkFilter);
                
                $startRow = $rows['controle'];
                $chunkFilter->setRows($startRow, $chunkSize);
                
                $objPHPExcel = $objReader->load($fileName);
                $sheetData = $objPHPExcel->getActiveSheet()->toArray(null,true,true,true);
                $tamanhoBloco = ($startRow + $chunkSize) - 1;
                
                if (!empty($sheetData) && count($sheetData) > 1) {
                    if((array_key_exists('ibpt',$rows ) && $rows['ibpt'])){
                        $this->aliquotaIBPT($sheetData, $rows, $array, $startRow, $tamanhoBloco, $chunkSize);
                    } else {
                        $this->importaImposto($sheetData, $rows, $array, $startRow, $tamanhoBloco, $chunkSize);
                    }
                    
                    
                    
                    
                }else{
                    self::escreverLog("Operação finalizada com sucesso! Data: ".date("d/m/Y H:i:s"));
                    self::escreverLog("Importações finalizadas com sucesso: ".$array['totalSuccess']);
                    self::escreverLog("Importações finalizadas com erros: ".$array['totalError']);
                    $array['log'] = $this->getLog();
                    $array['stop'] = true;
                    $array['status'] = true;
                    $array['message'] = "Rotina finalizada com sucesso!";
                    $array['controle'] = 1;
                }
                
                $objPHPExcel->disconnectWorksheets();
                unset($objPHPExcel, $sheetData);
                
            }else{
                $array['status'] = false;
                $array['message'] = "Não há dados do arquivo para processar!";
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('resultado', $array));
        } catch (\Exception $e) {
            
            self::escreverLog("## Erros Reportados na Importação ## ");
            self::escreverLog($e->getMessage());
            
            
            $array = array(
                "status" => false,
                "log" => $this->getLog(),
                'message' => "Erro ao realizar rotina!"
            );
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('resultado', $array));
        }
    }
    
    public function deleteXLS(Request $request, Response $response){
        $rows = $request->getRow();
        $array = array(
            "status" => '',
            "message" => ''
        );
        if(!empty($rows['diretorio']) && !empty($rows['file'])){
            $path = $rows['diretorio'].$rows['file'];
            if(unlink($path)){
                $array['status'] = true;
                $array['message'] = "Deletado com sucesso!";
            }else{
                $array['status'] = false;
                $array['message'] = "Erro ao deletar!";
            }
        }else{
            $array['status'] = false;
            $array['message'] = "Não há dados para conseguir deletar arquivo!";
        }
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('resultado', $array));
    }
    
    public function validaCabecalhoFilial($dados){
        
        $array = array(
            "status" => true,
            "message" => ''
        );
        
        if(!empty($dados)){
            $arrayCabecalho = $dados[1];
            if(!$this->validaCabecalho($arrayCabecalho)){
                $array['status'] = false;
                $array['message'] = 'Os dados do cabeçalho não confere com documentação!';
                return $array;
            }else{
                return $array;
            }
        }else{
            $array['status'] = false;
            $array['message'] = 'Não dados no arquivo para ser validados!';
            return $array;
        }
    }
    
    public function tratarDados($dados){
		$arrayRetorno = array();
		if(!empty($dados)){
			$arrayCabecalho = $dados[1];
			//retira o cabecalho
			unset($dados[1]);
			if(!empty($dados)){
			   foreach($dados as $key => $value){
    				if($this->verificaArrayVazio($value)){
    					foreach($value as $k => $v){
    						$arrayRetorno[$key][$arrayCabecalho[$k]] = $v;
    					}
    				}
    		   }
			}
		}
		return $arrayRetorno;
	}
	
	private function importaImposto($sheetData, $rows, &$array, $startRow, $tamanhoBloco, $chunkSize){
        $validation = $this->validaCabecalhoFilial($sheetData);
        if(!empty($validation)){
            if($validation['status']){
                $impostosProdutos = $this->tratarDados($sheetData);
                //chama funcao de salvar os dados
                $retorno = $this->AutoImpostoService->saveImpostoProduto($impostosProdutos, $rows['filial']);
                
                if($retorno['status']){
                	$array['status'] = true;
                	$array['message'] = "Bloco de ".$startRow." a ".$tamanhoBloco." processado...";
                	 
                	self::escreverLog("#######################################  Bloco de ".$startRow." a ".$tamanhoBloco." #######################################");
                
                	if(!empty($retorno['logRowsSucess'])){
                		self::escreverLog("## Impostos Inseridos com Sucesso ## ");
                		self::escreverLog($retorno['logRowsSucess']);
                		self::escreverLog("############################################################################");
                	}
                	
                	if(!empty($retorno['logRowsError'])){
                		self::escreverLog("## Produtos que não foram atualizados ## ");
                		self::escreverLog($retorno['logRowsError']);
                		self::escreverLog("############################################################################");
                	}
                	
                	$array['totalSuccess'] += $retorno['rowsSucess'];
                    $array['totalError'] += $retorno['rowsError'];
                	 
                }else{
                	$array['status'] = false;
                	$array['message'] = "Erro ao importar!". (isset($retorno['message'])) ? $retorno['message'] : '';
                	self::escreverLog($array['message']);
                }
                
            }else{
                $array['status'] = false;
                $array['message'] = $validation['message'];
            }
            
        }else{
            $array['status'] = false;
            $array['message'] = "Erro ao validar arquivo!";
        }
        self::escreverLog($array['message']);
        
        $array['controle'] = $startRow + $chunkSize;    
        $array['log'] = $this->getLog();
    }
	
	private function aliquotaIBPT($sheetData, $rows, &$array, $startRow, $tamanhoBloco, $chunkSize){
	    $validation = $this->validaCabecalhoFilialIBPT($sheetData);
                    if(!empty($validation)){
                        if($validation['status']){
                            $aliquota = $this->tratarDados($sheetData);
                            //chama funcao de salvar os dados
                            $retorno = $this->AutoImpostoService->saveAliquotaIBPT($aliquota, $rows['filial'], $array);
                            
                            if($retorno['status']){
                            	$array['status'] = true;
                            	$array['message'] = "Bloco de ".$startRow." a ".$tamanhoBloco." processado...";
                            	 
                            	self::escreverLog("#######################################  Bloco de ".$startRow." a ".$tamanhoBloco." #######################################");
                            
                            	if(!empty($retorno['logRowsSucess'])){
                            		self::escreverLog("## Aliquotas Inseridos com Sucesso ## ");
                            		self::escreverLog($retorno['logRowsSucess']);
                            		self::escreverLog("############################################################################");
                            	}
                            	
                            	if(!empty($retorno['logRowsError'])){
                            		self::escreverLog("## Produtos que não foram atualizados ## ");
                            		self::escreverLog($retorno['logRowsError']);
                            		self::escreverLog("############################################################################");
                            	}
                            	$array['totalSuccess'] += $retorno['rowsSucess'];
                                $array['totalError'] += $retorno['rowsError'];
                            	 
                            }else{
                            	$array['status'] = false;
                            	$array['message'] = "Erro ao importar!". (isset($retorno['message'])) ? $retorno['message'] : '';
                            	self::escreverLog($array['message']);
                            }
                            
                        }else{
                            $array['status'] = false;
                            $array['message'] = $validation['message'];
                        }
                        
                    }else{
                        $array['status'] = false;
                        $array['message'] = "Erro ao validar arquivo!";
                    }
                    self::escreverLog($array['message']);
                    
                     $array['controle'] = $startRow + $chunkSize;    
                     $array['log'] = $this->getLog();
	}
	
	private function validaCabecalho($arrayCabecalho){
		$retorno = true;
		$fieldsCabecalho = array(
    		'CODIGO',
    		'PRODUTO', 
    		'IMPOSTO', 
    		'ALIQUOTA', 
    		'PERCREDICMS', 
    		'MODBSCALCICMS', 
    		'INCPISCOFINS', 
    		'ALIQIBPTF', 
    		'ALIQIBPTE', 
    		'CDCFOP', 
    		'CDCSTCSOSNICMS', 
    		'CDCSTPISCOFINS', 
    		'ALIQPIS', 
    		'ALIQCOFINS'
        );
        
        
		foreach($fieldsCabecalho as $key => $value){
			if (!in_array($value, $arrayCabecalho)) {
				$retorno = false;
			}
		}
		return $retorno;
	}
	
	public function verificaArrayVazio($array){
		$retorno = false;
		foreach($array as $key => $value){
			if(!empty($value)){
				return true;
			}
		}
		return $retorno;
	}
	
	public function validaCabecalhoIBPT($arrayCabecalho){
	    $retorno = true;
	    $fieldsCabecalhoIBPT = array(
            'codigo',
            'ex',
            'tipo',
            'descricao',
            'nacionalfederal',
            'importadosfederal',
            'estadual',
            'municipal',
            'vigenciainicio',
            'vigenciafim',
            'chave',
            'versao',
            'fonte'
        );
        
        
		foreach($fieldsCabecalhoIBPT as $key => $value){
			if (!in_array($value, $arrayCabecalho)) {
				$retorno = false;
			}
		}
		return $retorno;
	    
	}
	
	public function validaCabecalhoFilialIBPT($dados){
        
        $array = array(
            "status" => true,
            "message" => ''
        );
        
        if(!empty($dados)){
            $arrayCabecalho = $dados[1];
            if(!$this->validaCabecalhoIBPT($arrayCabecalho)){
                $array['status'] = false;
                $array['message'] = 'Os dados do cabeçalho não confere com documentação!';
                return $array;
            }else{
                return $array;
            }
        }else{
            $array['status'] = false;
            $array['message'] = 'Não dados no arquivo para ser validados!';
            return $array;
        }
    }
    
    
}